@@ -1,3 +1,4 @@
+from django.contrib.auth.decorators import permission_required
 from django.shortcuts import redirect, render, get_object_or_404
 
 from wagtail.wagtailcore.models import Page
@@ -5,6 +6,7 @@ from wagtail.wagtailcore.models import Page
 from ..models import get_newsindex_content_types
 
 
+@permission_required('wagtailadmin.access_admin')  # further permissions are enforced within the view
 def choose(request):
     newsindex_list = Page.objects.filter(content_type__in=get_newsindex_content_types())
     newsindex_count = newsindex_list.count()
@@ -14,11 +16,12 @@ def choose(request):
 
     return render(request, 'wagtailnews/choose.html', {
         'has_news': newsindex_count != 0,
-        'newsindex_list': ((newsindex, newsindex.content_type.model_class().meta.verbose_name)
+        'newsindex_list': ((newsindex, newsindex.content_type.model_class()._meta.verbose_name)
                            for newsindex in newsindex_list)
     })
 
 
+@permission_required('wagtailadmin.access_admin')  # further permissions are enforced within the view
 def index(request, pk):
     newsindex = get_object_or_404(Page, pk=pk, content_type__in=get_newsindex_content_types()).specific
     NewsItem = newsindex.get_newsitem_model()
